@@ -1723,9 +1723,9 @@ class SMTOtuApi
      *
      * @return string
      */
-    static function updateHighsensTestCommand( $testId, $linkId, $traceOtdrName, $SOM, $EOM, $peakShift, $peakMonitoringType, $peakCount, $thresholdsBuffer, $peaksThresholdsBuffer, $peaksPositionsBuffer, $peakNames)
+    static function updateHighsensTestCommand( $testId, $linkId, $traceOtdrName, $SOM, $EOM, $peakShift, $peakMonitoringType, $peakCount, $thresholdsBuffer, $peaksThresholdsBuffer, $peaksPositionsBuffer, $peakNames, $monitoringAllowed)
     {
-    	return sprintf( self::CMD_highsens_test_update, $testId,0, 0, $linkId, self::RES_OK, self::RES_NO, $traceOtdrName, $SOM, $SOM, $EOM, $thresholdsBuffer, self::EMPTY_BUFFER,self::EMPTY_BUFFER,$peakCount,$peaksThresholdsBuffer,$peaksPositionsBuffer,$peakMonitoringType,$peakShift,$peakNames);
+    	return sprintf( self::CMD_highsens_test_update, $testId,0, 0, $linkId, $monitoringAllowed? self::RES_OK : self::RES_KO, self::RES_NO, $traceOtdrName, $SOM, $SOM, $EOM, $thresholdsBuffer, self::EMPTY_BUFFER,self::EMPTY_BUFFER,$peakCount,$peaksThresholdsBuffer,$peaksPositionsBuffer,$peakMonitoringType,$peakShift,$peakNames);
     }
     
     /**
@@ -2573,6 +2573,25 @@ class SMTOtuApi
     {
     	return sprintf(self::CMD_Api_changeSmartOTUCredential, $currentLogin, $currentPassword, $newLogin, $newPassword);
     }
+    
+    const CMD_Api_changeSmartOTUGuestCredential= "OTU:API:USER:GUEST \"%s\",\"%s\"";
+    static function changeSmartOTUGuestCredential($newLogin, $newPassword)
+    {
+    	return sprintf(self::CMD_Api_changeSmartOTUGuestCredential, $newLogin, $newPassword);
+    }
+    
+    const CMD_Api_SmartOTUGuestUser= "OTU:API:USER:ENAGuest %s";
+    static function enableSmartOTUGuestUser($enable)
+    {
+    	return sprintf(self::CMD_Api_changeSmartOTUCredential, $enable? 'TRUE' : 'FALSE');
+    }
+    
+    const CMD_Api_HasSmartOTUGuestUser= 'OTU:API:USER:ENAGuest?';
+    static function hasSmartOTUGuestUser()
+    {
+    	return self::CMD_Api_HasSmartOTUGuestUser;
+    }
+    
 }
 
 
