@@ -1,11 +1,13 @@
 <?php
 define("MSG_BAD_CREDENTIALS","提供的凭证 (登陆名或密码) 是无效的。");
 define("MSG_BAD_THRESHOLD_VALUE","对于区域： %s 为无效的阈值 %s");
+define("MSG_BAD_ROTAU_IP","无法使用IP地址％s连接到ROTAU");
 define("MSG_CHINESE","中文");
 define("MSG_CONNECTION","连接");
 define("MSG_COPYRIGHT_SHORT","版权 © 2019 VIAVI。 版权所有。");
-define("MSG_ENGLISH","英文");
+define("MSG_ENGLISH","English");
 define("MSG_ERROR_ADD_LOCALISATION_ERROR","添加本地化出错"); 
+define("MSG_ERROR_ALARM_UNDEFINED","未定义的警报");
 define("MSG_ERROR_ALARM_FETCH_FAILED","获取告警失败：");
 define("MSG_ERROR_APPLY_DATABASE_PATCH_FAILURE","数据库补丁应用失败！");
 define("MSG_ERROR_CLEAR_TEST_ALARM","消除测试告警失败！");
@@ -142,7 +144,7 @@ define("MSG_ERROR_WRONG_LASER","错误的激光器！");
 define("MSG_ERROR_WRONG_PULSE","错误的脉宽！"); 
 define("MSG_ERROR_WRONG_RANGE","错误的范围！"); 
 define("MSG_ERROR_WRONG_RES","错误的分辨率！"); 
-define("MSG_FRENCH","法语");
+define("MSG_FRENCH","Français");
 define("MSG_INVALID_LOG_LEVEL_PARAMETER","无效的日志级别参数，应该是：%s");
 define("MSG_INVALID_VALUE_EXCEPTION","无效的参数值：%s");
 define("MSG_INVALID_STATUS","无效的操作状态！");
@@ -229,6 +231,7 @@ define("PEAK","峰");
 define("PERSISTENT_FAILURE","持续的失败");
 define("PON_FAILURE","PON测试失败");
 define("OTU_SYST_ALARM_POWER_FAILURE","电源（检测）失败");
+define("OTU_SYST_REFERENCE_DRIFT_FAILURE","参考迹线漂移");
 define("RAMAN_POWER_DETECTION","拉曼激光器功率检测");
 define("RAMAN_POWER_DECREASE","拉曼激光器功率下降");
 define("REBOOT","重启");
@@ -241,6 +244,9 @@ define("TEMPORARY_PROBLEM","临时性问题");
 define("TEST_MEDIA","介质测试");
 define("TIMEOUT_ON_MONITORING_TEST_CYCLE","监测周期内超时");
 define("THRESHOLD_LEVEL_EXCEEDED","超过阈值");
+define("CONNECTOR_FAILURE","连接器");
+define("CONNECTOR_FIBER_CUT_FAILURE","光纤切割（连接器)");
+define("CONNECTOR_ATTENUATION_FAILURE","超过阈值 (连接器)");
 define("UNKNOW_ALARM","未知的告警");
 define("UNKNOWN_CAUSE","未知的原因");
 ?>
