@@ -1,11 +1,13 @@
 <?php
 define("MSG_BAD_CREDENTIALS","Les identifiants fournis (nom d’utilisateur ou mot de passe) sont invalides.");
 define("MSG_BAD_THRESHOLD_VALUE","La valeur de seuil %s est incorrecte pour le champs: %s");
-define("MSG_CHINESE","Chinois");
+define("MSG_BAD_ROTAU_IP","Impossible de se connecter au ROTAU d'adresse %s");
+define("MSG_CHINESE","中文");
 define("MSG_CONNECTION","Connexion");
 define("MSG_COPYRIGHT_SHORT","Copyright © 2019 VIAVI. Tous droits réservés.");
-define("MSG_ENGLISH","Anglais");
+define("MSG_ENGLISH","English");
 define("MSG_ERROR_ADD_LOCALISATION_ERROR","Erreur d ajout de localisation!"); 
+define("MSG_ERROR_ALARM_UNDEFINED","Alarme inconnue");
 define("MSG_ERROR_ALARM_FETCH_FAILED","Echec lors de la récupération d'une alarme: ");
 define("MSG_ERROR_APPLY_DATABASE_PATCH_FAILURE","Les patches de la base de données n'ont pas pu être appliqués!");
 define("MSG_ERROR_CLEAR_TEST_ALARM","Erreur lors de la suppression des alarmes du test!");
@@ -205,7 +207,7 @@ define("LINKS_BACK_TO_AVAILABLE","Les liaisons sont de nouveau disponibles");
 define("LOCAL_MODE","Mode local");
 define("MISSING_REFERENCE_FILE","Fichier de référence absent!");
 define("MODULE_AUTOCONFIGURATION","Autoconfiguration du module OTDR");
-define("MODULE_TEMPERATURE","Problème de température du module OTDR");
+define("MODULE_TEMPERATURE","Problème de température du module");
 define("MONITORING_CYCLE","Cycle de surveillance");
 define("MONITORING_TEST_DRIFT","Dérive du test de surveillance");
 define("NO_PROBLEM_DETECTED","Aucun problème détecté");
@@ -230,6 +232,7 @@ define("OTU_SYST_ALARM_POWER_FAILURE","Perte d'alimentation");
 define("PEAK","Pic");
 define("PERSISTENT_FAILURE","Persistence du défaut");
 define("PON_FAILURE","Echec du test PON");
+define("OTU_SYST_REFERENCE_DRIFT_FAILURE","Dérive de la courbe de référence");
 define("RAMAN_POWER_DETECTION","Puissance RAMAN");
 define("RAMAN_POWER_DECREASE","Baisse de la puissance RAMAN");
 define("REBOOT","Reboot");
@@ -242,6 +245,9 @@ define("TEMPORARY_PROBLEM","Problème temporaire");
 define("TEST_MEDIA","Test des media");
 define("TIMEOUT_ON_MONITORING_TEST_CYCLE","Dépassement du temps imparti pour le lancement du test de surveillance");
 define("THRESHOLD_LEVEL_EXCEEDED","Dépassement de niveau");
+define("CONNECTOR_FAILURE","Connecteur");
+define("CONNECTOR_FIBER_CUT_FAILURE","Coupure fibre (Connecteur)");
+define("CONNECTOR_ATTENUATION_FAILURE","Dépassement de niveau (Connecteur)");
 define("UNKNOW_ALARM","Alarme inconnue");
 define("UNKNOWN_CAUSE","Cause inconnue");
 ?>
