@@ -15,24 +15,23 @@ namespace app\services\alarm;
 
 use app\serviceshelper\media\SMTWebService;
 
-use app\util\SMTUtil;
-use app\util\SMTStatusDto;
-use app\util\SMTLogger;
-use app\util\SMTIOException;
-use app\settings\SMTSmartOtuSettings;
+use app\error\SMTAccessForbiddenRestException;
+use app\events\SMTEventMessageManager;
 use app\parser\SMTOtuApi;
+use app\services\security\SMTAccessControl;
 use app\services\SMTIService;
 use app\services\SMTService;
-use app\services\security\SMTAccessControl;
-use app\events\SMTEventMessageManager;
-use app\view\SMTTestRestApiPage;
-use app\view\SMTFileDownloadPage;
 use app\serviceshelper\alarm\SMTAlarm;
 use app\serviceshelper\alarm\SMTAlarmFactory;
 use app\serviceshelper\monitoring\SMTGpsRoute;
 use app\serviceshelper\monitoring\SMTLinkTest;
-use app\admin\SMTAuthenticationException;
-use app\error\SMTAccessForbiddenRestException;
+use app\settings\SMTSmartOtuSettings;
+use app\util\SMTIOException;
+use app\util\SMTLogger;
+use app\util\SMTStatusDto;
+use app\util\SMTUtil;
+use app\view\SMTFileDownloadPage;
+use app\view\SMTTestRestApiPage;
 
 /**
  * Service to clear and list alarms.
@@ -208,7 +207,7 @@ class SMTAlarmService extends SMTService implements SMTIService
      *
      *
      * @access protected
-     * @class SMTAccessControl {@requires user}
+     * @class SMTAccessControl {@requires install}
      */
     function clearAllAlarms()
     {
@@ -298,7 +297,7 @@ class SMTAlarmService extends SMTService implements SMTIService
      * @status 200
      *
      * @access protected
-     * @class SMTAccessControl {@requires user}
+     * @class SMTAccessControl {@requires install}
      */
     function clearSystemAlarm( $id )
     {
@@ -326,15 +325,15 @@ class SMTAlarmService extends SMTService implements SMTIService
      * id = alarm identifier
      * Can be accessed outside SmartOTU: no security access
      *
+     * @param $serverName
+     * @param $linkId
+     * 
      * @url GET /kml/{id}
      */
-    function downloadKmlAlarm( $id, $request_data )
+    function downloadKmlAlarm( $id, $serverName, $linkId )
     {
     	try
     	{
-    	    $serverName = $request_data['serverName'];
-    	    $linkId = $request_data['linkId'];
-    	    
     	    $linkHelper = new SMTLinkTest();
     	    $linkHelper->setContext( $this->getContext() );
     	    $linkDto = $linkHelper->retrieveLinkInfo( $linkId );
