@@ -152,7 +152,7 @@ class SMTMaintenanceService extends SMTService implements SMTIService
      * @url POST /system/reboot
      *
      * @access protected
-     * @class SMTAccessControl {@requires user}
+     * @class SMTAccessControl {@requires install}
      */
     function reboot()
     {
@@ -227,18 +227,16 @@ class SMTMaintenanceService extends SMTService implements SMTIService
       
 //     /**
 //      * Request to download the given log file...
-//      *
+//      * @param $fileName
 //      * @url GET /log
 //      * @status 200
 //      * @access protected
 //      * @class SMTAccessControl {@requires install}
 //      */
-//     function downloadLogFile( $request_data )
+//     function downloadLogFile( $fileName)
 //     {    	
 //     	try
 //     	{
-//     	    $fileName = $request_data['fileName'];
-    	    
 //     	    $logFileName = SMTOtuDebug::retrieveLogFileName($fileName);
     	    
 //         	if ( $logFileName != NULL )
@@ -395,7 +393,7 @@ class SMTMaintenanceService extends SMTService implements SMTIService
      *
      * @url GET /saa
      * @access protected
-     * @class SMTAccessControl {@requires install}
+     * @class SMTAccessControl {@requires user}
      */
     function fetchSaaSetup()
     {
@@ -622,6 +620,8 @@ class SMTMaintenanceService extends SMTService implements SMTIService
     		$licenseHelper = new SMTLicence();
     		$licenseHelper->setContext( $this->getContext() );
     
+    		$filename = strip_tags($filename);
+    		
     		if ( !empty( $filename ) )
     		{
   			    $licenseHelper->processLicense($filename);
@@ -650,7 +650,7 @@ class SMTMaintenanceService extends SMTService implements SMTIService
      * @url GET /system/license
      *
      * @access protected
-     * @class SMTAccessControl {@requires install}
+     * @class SMTAccessControl {@requires user}
      */
     function getLicense()
     {
@@ -673,7 +673,9 @@ class SMTMaintenanceService extends SMTService implements SMTIService
      * Start the upgrade of the OTU file system
      *
      * @url POST /system/filesystem
-     *
+     * 
+     * @access protected
+     * @class SMTAccessControl {@requires install}
      */
     function startFileSystemUpgrade()
     {
@@ -713,6 +715,9 @@ class SMTMaintenanceService extends SMTService implements SMTIService
      * Start the upgrade of the OTU rescue
      *
      * @url POST /system/rescue
+     * 
+     * @access protected
+     * @class SMTAccessControl {@requires install}
      */
     function startRescueUpgrade()
     {
@@ -750,7 +755,7 @@ class SMTMaintenanceService extends SMTService implements SMTIService
      * @url POST /system/upgrade
      *
      * @access protected
-     * @class SMTAccessControl {@requires install}
+     * @class SMTAccessControl {@requires user}
      */
     function getUpgradeInfo()
     {
@@ -775,7 +780,7 @@ class SMTMaintenanceService extends SMTService implements SMTIService
      * @url GET /system/upgrade
      *
      * @access protected
-     * @class SMTAccessControl {@requires install}
+     * @class SMTAccessControl {@requires user}
      */
     function getCurrentUpgrade()
     {
@@ -800,7 +805,7 @@ class SMTMaintenanceService extends SMTService implements SMTIService
      * @url GET /upload/{id}
      * 
      * @access protected
-     * @class SMTAccessControl {@requires install}
+     * @class SMTAccessControl {@requires user}
      */
     function getUploadStatus( $id )
     {
@@ -918,7 +923,7 @@ class SMTMaintenanceService extends SMTService implements SMTIService
      * @url GET /system/backup/current/name
      *
      * @access protected
-     * @class SMTAccessControl {@requires install}
+     * @class SMTAccessControl {@requires user}
      */
     function getCurrentBackupName()
     {
@@ -999,25 +1004,28 @@ class SMTMaintenanceService extends SMTService implements SMTIService
      */
     function testTestIp($command,$parameters,$isquery)
     {    
-    	$url = '/maintenance/system/testip';
-    	$isQuery = filter_var($isquery, FILTER_VALIDATE_BOOLEAN);
-    	if ($isQuery)
+    	if ( SMTSmartOtuSettings::isDebugMode() )
     	{
-    	    $command = urldecode( $command )."? ".$parameters;
-    	    SMTLogger::getInstance()->trace("command: ".$command);
+	    	$url = '/maintenance/system/testip';
+	    	$isQuery = filter_var($isquery, FILTER_VALIDATE_BOOLEAN);
+	    	if ($isQuery)
+	    	{
+	    	    $command = urldecode( $command )."? ".$parameters;
+	    	    SMTLogger::getInstance()->trace("command: ".$command);
+	    	}
+	    	else
+	    	{
+	    	    $command = urldecode( $command )." ".$parameters;
+	    	    SMTLogger::getInstance()->trace("command: ".urldecode( $command ) );
+	    	}
+	    	$testIpDTO = new SMTTestIpDto();
+	    	$testIpDTO->setCommand( $command );    	
+	    	$testIpDTO->setQuery( $isQuery );
+	    	
+	    	$json_string = json_encode( $testIpDTO->getJsonData() );
+	    	$page = new SMTTestRestApiPage($url, $json_string, 'POST');
+	    	$this->getContext()->getHttpResponse()->send( $page );
     	}
-    	else
-    	{
-    	    $command = urldecode( $command )." ".$parameters;
-    	    SMTLogger::getInstance()->trace("command: ".urldecode( $command ) );
-    	}
-    	$testIpDTO = new SMTTestIpDto();
-    	$testIpDTO->setCommand( $command );    	
-    	$testIpDTO->setQuery( $isQuery );
-    	
-    	$json_string = json_encode( $testIpDTO->getJsonData() );
-    	$page = new SMTTestRestApiPage($url, $json_string, 'POST');
-    	$this->getContext()->getHttpResponse()->send( $page );
     }   
     
     /**
@@ -1050,14 +1058,15 @@ class SMTMaintenanceService extends SMTService implements SMTIService
     
     
     /**
-     *
+     * 
+     * @param $stringToTest
+     * 
      * @url GET /test/regexp
      */
-    function testRegexp( $request_data )
+    function testRegexp( $stringToTest)
     {
         if ( SMTSmartOtuSettings::isDebugMode() )
         {
-            $stringToTest = $request_data['stringToTest'];
             var_dump(SMTUtil::splitStringByComma($stringToTest));
         }
     }    
