@@ -243,7 +243,7 @@ class SMTLinkTestService extends SMTService implements SMTIService
      *
      * @url DELETE /{id}
      * @access protected
-     * @class SMTAccessControl {@requires user}
+     * @class SMTAccessControl {@requires install}
      */
     function deleteLinkTest( $id )
     {
@@ -330,7 +330,7 @@ class SMTLinkTestService extends SMTService implements SMTIService
      *
      * @url DELETE /test/{testid}
      * @access protected
-     * @class SMTAccessControl {@requires user}
+     * @class SMTAccessControl {@requires install}
      */
     function deleteTest( $testid )
     {
@@ -404,7 +404,7 @@ class SMTLinkTestService extends SMTService implements SMTIService
      * 
      * @url PUT /{id}/name/{newname}
      * @access protected
-     * @class SMTAccessControl {@requires user}
+     * @class SMTAccessControl {@requires install}
      */    
     function renameLinkTest( $id, $newname )
     {
@@ -412,6 +412,7 @@ class SMTLinkTestService extends SMTService implements SMTIService
         {            
             $linkHelper = new SMTLinkTest();
             $linkHelper->setContext( $this->getContext() );
+            $newname = strip_tags($newname);
             $linkHelper->renameLinkTest($id, $newname );
             $linkDto = $linkHelper->retrieveLinkTest( $id );
         }
@@ -431,7 +432,7 @@ class SMTLinkTestService extends SMTService implements SMTIService
      * @url PUT /{id}/available/{measureAllowed}/{monitoringAllowed}
      * 
      * @access protected
-     * @class SMTAccessControl {@requires user}
+     * @class SMTAccessControl {@requires install}
      */    
     function setLinkTestAvailable( $id, $measureAllowed, $monitoringAllowed )
     {
@@ -669,7 +670,7 @@ class SMTLinkTestService extends SMTService implements SMTIService
      * @url DELETE /test/{testid}/alarm/
      *
      * @access protected
-     * @class SMTAccessControl {@requires user}
+     * @class SMTAccessControl {@requires install}
      */
     function deleteOpticalAlarm( $testId )
     {
@@ -1023,7 +1024,7 @@ class SMTLinkTestService extends SMTService implements SMTIService
      * @url POST /{portNumber}/{moduleRunningNumber}/init
      *
      * @access protected
-     * @class SMTAccessControl {@requires user}
+     * @class SMTAccessControl {@requires install}
      */
     function initLinkTest( $portNumber, $moduleRunningNumber )
     {
@@ -1049,7 +1050,7 @@ class SMTLinkTestService extends SMTService implements SMTIService
      * @url POST /{id}/init
      *
      * @access protected
-     * @class SMTAccessControl {@requires user}
+     * @class SMTAccessControl {@requires install}
      */
     function initTestDetail( $id, $request_data)
     {
@@ -1137,7 +1138,7 @@ class SMTLinkTestService extends SMTService implements SMTIService
      * @url POST /{id}/kml/{filename}
      *
      * @access protected
-     * @class SMTAccessControl {@requires user}
+     * @class SMTAccessControl {@requires install}
      */
     function processKml( $id, $filename )
     {
@@ -1150,17 +1151,19 @@ class SMTLinkTestService extends SMTService implements SMTIService
     		$linkHelper->setContext( $this->getContext() );    		    		
     		$linkDto = $linkHelper->retrieveLinkTest( $id );
     		//remove old gps file already associated
-    		$gpsFileName = $linkDto->getGpsFileName(); 
-    		if ( !empty( $gpsFileName ) )
+    		$gpsFileName = $linkDto->getGpsFileName();
+    		//delete old file only if it has not the same name (fix remove the uploaded file!)
+    		if ( !empty( $gpsFileName ) && strcmp($gpsFileName.'.kml', $filename) != 0 )
     		{
-    		    try 
-    		    {
-    		    	$kmlHelper->deleteKml($gpsFileName, $id);
-    		    }
-    		    catch( \Exception $ex)
-    		    {
-    		        $this->getContext()->getLogger()->traceException($ex);
-    		    }
+    			try
+    			{
+    				//$this->getContext()->getLogger()->trace("$gpsFileName , $filename");
+    				$kmlHelper->deleteKml($gpsFileName, $id);
+    			}
+    			catch( \Exception $ex)
+    			{
+    				$this->getContext()->getLogger()->traceException($ex);
+    			}
     		}
     		//remove old gps file
     		SMTGpsRoute::removeOldKmlFileName($id);
@@ -1183,7 +1186,7 @@ class SMTLinkTestService extends SMTService implements SMTIService
      * @url DELETE /{id}/kml
      *
      * @access protected
-     * @class SMTAccessControl {@requires user}
+     * @class SMTAccessControl {@requires install}
      */
     function deleteKml( $id )
     {
@@ -1319,7 +1322,7 @@ class SMTLinkTestService extends SMTService implements SMTIService
      * @url POST /mode/{mode}
      *
      * @access protected
-     * @class SMTAccessControl {@requires user}
+     * @class SMTAccessControl {@requires install}
      */
     function setOtuLegacyMonitoringMode($mode)
     {
