@@ -985,7 +985,7 @@ class SMTLinkTest extends SMTServiceHelper
     		
     		//update test detection and localization
     		$peakMonitoringType= self::getOtuMonitoringType($linkTestDto->getTestDetail()->getPeakShiftMode(), ($peakCount > 0));
-    		$this->send( SMTOtuApi::updateHighsensTestCommand( $linkTestDto->getTestId(), $linkTestDto->getId(), $referenceTraceNameWithoutExtension, $linkTestDto->getTestDetail()->getFirstMarkerDistanceM(), $linkTestDto->getTestDetail()->getLastMarkerDistanceM(), $linkTestDto->getTestDetail()->getMissingPeakThresholdPt(), $peakMonitoringType, $peakCount, $thresholdsBuffer, $peakThresholdsBuffer, $peaksPositionsBuffer, $peakNames) );
+    		$this->send( SMTOtuApi::updateHighsensTestCommand( $linkTestDto->getTestId(), $linkTestDto->getId(), $referenceTraceNameWithoutExtension, $linkTestDto->getTestDetail()->getFirstMarkerDistanceM(), $linkTestDto->getTestDetail()->getLastMarkerDistanceM(), $linkTestDto->getTestDetail()->getMissingPeakThresholdPt(), $peakMonitoringType, $peakCount, $thresholdsBuffer, $peakThresholdsBuffer, $peaksPositionsBuffer, $peakNames, $linkTestDto->isMonitoringAllowed()) );
     	}
     	catch ( \Exception $e )
     	{
