@@ -52,7 +52,14 @@ class SMTSmartOtuSettingsCache extends SMTDto implements SMTIMemorySupport
      *
      * @var string
      */
-    private $otuMode = NULL;    
+    private $otuMode = NULL;
+    
+    /**
+     * OTU option.
+     *
+     * @var string
+     */
+    private $otuOption = NULL;
     
     /**
      * OTU type.
@@ -98,7 +105,13 @@ class SMTSmartOtuSettingsCache extends SMTDto implements SMTIMemorySupport
      * Whether the SMS option is available on the OTU or NULL if the data wasn't yet retrieved
      * @var boolean
      */
-    protected $smsOptionValid = NULL;    
+    protected $smsOptionValid = NULL;
+    
+    /**
+     * Whether the relay option is available on the OTU or NULL if the data wasn't yet retrieved
+     * @var boolean
+     */
+    protected $relayOptionValid = NULL;
 
     /**
      * Whether attenuation monitoring critical thresholds are set in OTU
@@ -126,21 +139,36 @@ class SMTSmartOtuSettingsCache extends SMTDto implements SMTIMemorySupport
      *  
      * @var float
      */
-    private $monitoringAcceptableNoiseMarginDbDefault = SMTSmartOtuThresholds::DEFAULT_MONITORING_ACCEPTABLE_NOISE_MARGIN_DB_DEFAULT;    
+    private $monitoringAcceptableNoiseMarginDbDefault = NULL;
+    
+    /**
+     * Tapping Acceptable Noise Margin in Db.
+     * Used to display that min noise level in trace viewer and to force user to set markers in traceviewer outside noise level.
+     *
+     * @var float
+     */
+    private $tappingAcceptableNoiseMarginDbDefault = NULL;
     
     /**
      * Attenuation critical threshold (in Db)
      * 
      * @var float
      */
-    private $attenuationCriticalThresholdDbDefault = SMTSmartOtuThresholds::DEFAULT_ATTENUATION_CRITICAL_THRESHOLD;
+    private $attenuationCriticalThresholdDbDefault = NULL;
     
     /**
      * The default delta between TO and BACK TO thresholds for attenuation in Db
      * 
      * @var float
      */
-    private $attenuationToBtoDeltaDbDefault = SMTSmartOtuThresholds::DEFAULT_MONITORING_ATTENUATION_TO_AND_BACK_TO_DELTA_DB_DEFAULT;
+    private $attenuationToBtoDeltaDbDefault = NULL;
+
+    /**
+     * The default delta between TO and BACK TO thresholds for attenuation in Db
+     *
+     * @var float
+     */
+    private $tappingToBtoDeltaDbDefault = NULL;
     
     //PEAK monitoring (NULL to force to retrieve value from ini file)
     private $peakToBtoDeltaDefault = NULL;
@@ -159,12 +187,20 @@ class SMTSmartOtuSettingsCache extends SMTDto implements SMTIMemorySupport
      */
     private $budgetVariationThresholds = NULL;
     
+    /**
+     * @SMTAttributeInfosAnnotation(classname='app\serviceshelper\monitoring\SMTOtuMonitoringTestThresholdDto')
+     * @var app\serviceshelper\monitoring\SMTOtuMonitoringTestThresholdDto
+     */
+    private $tappingThresholds = NULL;
+    
     /**
      * @SMTAttributeInfosAnnotation(classname='app\serviceshelper\monitoring\SMTOtuMonitoringTestThresholdDto')
      * @var app\serviceshelper\monitoring\SMTOtuMonitoringTestThresholdDto
      */
     private $peaksThresholdsDb= NULL;
     
+    private $restApi = NULL;
+    
     /**
      * @return string
      */
@@ -292,7 +328,26 @@ class SMTSmartOtuSettingsCache extends SMTDto implements SMTIMemorySupport
     {
     	return $this->otuMode;
     }
+    /**
+     * Set the otu mode in CACHE MEMORY.
+     *
+     * @param string $otuOption
+     */
+    public function setOtuOption($otuOption)
+    {
+    	$this->otuOption= $otuOption;
+    }
     
+    /**
+     * Returns the otu mode from CACHE MEMORY.
+     *
+     * @return string
+     */
+    public function getOtuOption()
+    {
+    	return $this->otuOption;
+    }
+
     /**
      * Set the otu type in CACHE MEMORY.
      *
@@ -331,7 +386,27 @@ class SMTSmartOtuSettingsCache extends SMTDto implements SMTIMemorySupport
     public function getMapUrl()
     {
     	return $this->mapUrl;
-    }    
+    }
+    
+    /**
+     * Set whether the API REST can be used.
+     *
+     * @param boolean $valid
+     */
+    public function setRestApi($valid)
+    {
+    	$this->restApi = $valid;
+    }
+    
+    /**
+     * Returns the google map url from CACHE MEMORY.
+     *
+     * @return boolean
+     */
+    public function isRestApi()
+    {
+    	return $this->restApi;
+    }
     
     /**
      * Set log level
@@ -421,7 +496,24 @@ class SMTSmartOtuSettingsCache extends SMTDto implements SMTIMemorySupport
     public function isSmsOptionValid()
     {
     	return $this->smsOptionValid;
-    }    
+    }
+    
+    /**
+     * @param boolean $valid
+     */
+    public function setRelayOptionValid ( $relayOptionValid )
+    {
+    	$this->relayOptionValid= $relayOptionValid;
+    }
+    
+    /**
+     * Whether the relay option is available on the OTU or NULL if the data wasn't yet retrieved
+     * @return boolean or NULL
+     */
+    public function isRelayOptionValid()
+    {
+    	return $this->relayOptionValid;
+    }
     
     /**
      * @param app\serviceshelper\monitoring\SMTOtuMonitoringTestThresholdDto $peaksThresholdsDb
@@ -453,7 +545,15 @@ class SMTSmartOtuSettingsCache extends SMTDto implements SMTIMemorySupport
     function setDefaultBudgetVariationThresholds( $budgetVariationThresholds )
     {
     	$this->budgetVariationThresholds = $budgetVariationThresholds;
-    }            
+    }
+    
+    /**
+     * @param app\serviceshelper\monitoring\SMTOtuMonitoringTestThresholdDto $tappingThresholds
+     */
+    function setDefaultTappingThresholds( $tappingThresholds)
+    {
+    	$this->tappingThresholds = $tappingThresholds;
+    }
     
     /**
      * @return \app\serviceshelper\monitoring\SMTOtuMonitoringTestThresholdDto
@@ -469,7 +569,15 @@ class SMTSmartOtuSettingsCache extends SMTDto implements SMTIMemorySupport
     function getDefaultBudgetVariationThresholds( )
     {
     	return $this->budgetVariationThresholds;
-    }    
+    }
+    
+    /**
+     * @return \app\serviceshelper\monitoring\SMTOtuMonitoringTestThresholdDto
+     */
+    function getDefaultTappingThresholds( )
+    {
+    	return $this->tappingThresholds;
+    }
     
     /**
      * @return float
@@ -478,14 +586,30 @@ class SMTSmartOtuSettingsCache extends SMTDto implements SMTIMemorySupport
     {
     	return $this->monitoringAcceptableNoiseMarginDbDefault;
     }
-
+    
     /**
      * @param float $monitoringAcceptableNoiseMarginDbDefault
      */
     function setMonitoringAcceptableNoiseMarginDbDefault( $monitoringAcceptableNoiseMarginDbDefault )
     {
     	$this->monitoringAcceptableNoiseMarginDbDefault = $monitoringAcceptableNoiseMarginDbDefault;
-    }    
+    }
+
+    /**
+     * @return float
+     */
+    function getTappingAcceptableNoiseMarginDbDefault( )
+    {
+    	return $this->tappingAcceptableNoiseMarginDbDefault;
+    }
+    
+    /**
+     * @param float $tappingAcceptableNoiseMarginDbDefault
+     */
+    function setTappingAcceptableNoiseMarginDbDefault( $tappingAcceptableNoiseMarginDbDefault )
+    {
+    	$this->tappingAcceptableNoiseMarginDbDefault= $tappingAcceptableNoiseMarginDbDefault;
+    }
     
     /**
      * @return float
@@ -521,6 +645,24 @@ class SMTSmartOtuSettingsCache extends SMTDto implements SMTIMemorySupport
         $this->attenuationToBtoDeltaDbDefault = $attenuationToBtoDeltaDbDefault;
     }
     
+    /**
+     * @return float
+     */
+    function getTappingToBtoDeltaDbDefault( )
+    {
+    	return $this->tappingToBtoDeltaDbDefault;
+    }
+    
+    /**
+     * Register the delta between TO and BACK TO thresholds for tapping attenuation (in Db) in cache and in settings
+     *
+     * @param SMTOtuMonitoringTestThresholdDto $attenuationToBtoDeltaDbDefault The delta between TO and BACK TO thresholds for tapping attenuation (in Db)
+     */
+    public function setTappingToBtoDeltaDbDefault( $attenuationToBtoDeltaDbDefault  )
+    {
+    	$this->tappingToBtoDeltaDbDefault = $attenuationToBtoDeltaDbDefault;
+    }
+    
     /**
      * @return float
      */
