@@ -201,12 +201,12 @@ class SMTLogger
     
     /**
      * Date string in "absolute time": not in UTC
-     * 
+     * Month date h:m::s
      * @return string
      */
     public static function getDate()
     {
-        return date("D j H:i:s");
+        return date("M j H:i:s");
     }
     
     /**
