@@ -6,6 +6,7 @@ function Disconnect
    # on supprime la mmorisation de la connexion avant de faire tomber la connexion ssh afin que le processus dtach qui surveille 
    # la connexion n'envoie pas un message d"erreur erron indiquant un problme rseau
    $uboot_environment_set MtsAnywhere
+   rm -f /tmp/param_mts*
    
    # deconnexion, on essaye les diffrents chemins jusqu' aboutir
    kill $(ps aux | grep ssh | grep MAW_Connection | grep param_mts | tr -s " " | cut -d " " -f 2)
@@ -34,6 +35,22 @@ function Disconnect
    
 }
 
+function Warning_Connection_Failed
+{
+   ethernet=$(nmcli -f general.devices  c show "JDSU WIRED")
+   wifi=$(nmcli -f general.devices  c show "JDSU WIFI")
+   usb3g=$(nmcli -f general.devices  c show "MTS ANYWHERE")
+
+   if [ "$ethernet" == "" -a "$wifi" == "" -a "$usb3g" == "" ]
+      then
+      # affichage warning indiquant echec connexion du  l'absence de connectivit
+      echo -en "*rem\nproc:warn \"\",\"Connection failed\nno IP address anymore. Check Ethernet cable, wifi or tethering state\",error,0,\"\",\"\",\"Hit any key to continue\"\n" >/dev/tcp/127.0.0.1/8000
+   else   
+      # affichage warning gnrique indiquant echec connexion
+      echo -en "*rem\nprocess:warning \"\",\"Connection failed\", ERROR, 0,\"\",\"\",\"Hit any key to continue\"\n" >/dev/tcp/127.0.0.1/8000
+   fi   
+}
+
 # Fermeture des fd de ce processus, fd hrits du process parent Isu,  de faon  pouvoir faire un restart_Isu sans tout bloquer 
 for fd in $(ls /proc/$$/fd)
    do
@@ -278,7 +295,7 @@ if [ "$1" == "CONNECT" -o "$1" == "RECONNECT" ]
                echo -en "*rem\nprocess:warning \"\",\"Server ports not available\nRetry in some minutes\", WARNING, 0,\"\",\"\",\"Hit any key to continue\"\n" >/dev/tcp/127.0.0.1/8000
             else
                # affichage warning indiquant echec connexion 
-               echo -en "*rem\nprocess:warning \"\",\"Connection failed\", ERROR, 0,\"\",\"\",\"Hit any key to continue\"\n" >/dev/tcp/127.0.0.1/8000
+               Warning_Connection_Failed
             fi
          fi
       else
@@ -295,6 +312,12 @@ if [ "$1" == "CONNECT" -o "$1" == "RECONNECT" ]
                # en cas de reconnexion automatique, on efface au contraire la memorisation pour ne pas repeter le reconnexion a l'infini
                $uboot_environment_set MtsAnywhere
             fi
+            
+            if [ "$Media" == wlan ]
+               # En cas de connexion via wifi, on force autoconnect de faon  ne pas perdre la connexion SAA si le rseau "bafouille"
+               then
+               nmcli c modify "$(nmcli c | grep -o "JDSU WIFI")" connection.autoconnect yes connection.autoconnect-priority 10
+               fi
    
             # si il n'y a pas deja un serveur x11vnc actif, alors on le lance (sans password)  et on l'arrete quand la connexion ssh tombe
             # Le test est plus complexe  cause du 4000v2 dans lequel Isu lance /etc/init.d/x11vnc connections pour connaitre le nombre de
@@ -311,7 +334,7 @@ if [ "$1" == "CONNECT" -o "$1" == "RECONNECT" ]
                # ou le fichier /var/run/x11vnc.pid dans le cas du 4000v2
                rm -f $vnc_id
     
-               while [ -d /proc/$Ssh_Pid ]
+               while [ "$($uboot_environment_get MtsAnywhere)" != "" ] || [ -d /proc/$Ssh_Pid ]
                   do
                   sleep 10
                   done
@@ -330,33 +353,63 @@ if [ "$1" == "CONNECT" -o "$1" == "RECONNECT" ]
             ( (
             if [ "$Ssh_Pid" != "$Prev_Ssh_Pid" ]
                then
-               while [ -d /proc/$Ssh_Pid ]
-                  do
-                  CurrentMedia=$(route | grep default | head -n1 | awk '{print $8}' | sed "s/[0-9]//g")
-                  if [ "$CurrentMedia" != "$Media" -a "$CurrentMedia" != "" ]
+               Wait_Before_Restart_Connection=0
+               while [ "$($uboot_environment_get MtsAnywhere)" != "" ]  
+                  do 
+                  if [ -d /proc/$Ssh_Pid ]
                      then
-                     kill $(ps aux | grep ssh | grep MAW_Connection | grep param_mts | tr -s " " | cut -d " " -f 2)
-                     $uboot_environment_set MtsAnywhere
-                     echo "*rem;proc:mtsanywhere off" | nc -w2 127.0.0.1 8000
-                     if [ "$1" == "CONNECT" ] && [ "$IS_OTU" == "no" ]
+                     CurrentMedia=$(route | grep default | head -n1 | awk '{print $8}' | sed "s/[0-9]//g")
+                     if [ "$CurrentMedia" != "$Media" -a "$CurrentMedia" != "" ]
                         then
-                        echo -en "*rem\nprocess:warning \"\",\"SmartAcces connection lost\nDefault network route is no more the one used for connection\", STOP, 1,\"OK\",\"\",\"Press OK to continue\"\n" >/dev/tcp/127.0.0.1/8000
-                     fi   
+                        rm -f /tmp/param_mts*
+                        kill $(ps aux | grep ssh | grep MAW_Connection | grep param_mts | tr -s " " | cut -d " " -f 2)
+                        $uboot_environment_set MtsAnywhere
+                        echo "*rem;proc:mtsanywhere off" | nc -w2 127.0.0.1 8000
+                        if [ "$1" == "CONNECT" ] && [ "$IS_OTU" == "no" ]
+                           then
+                           echo -en "*rem\nprocess:warning \"\",\"SmartAcces connection lost\nDefault network route is no more the one used for connection\", STOP, 1,\"OK\",\"\",\"Press OK to continue\"\n" >/dev/tcp/127.0.0.1/8000
+                        fi   
+                     fi
+                     sleep 10
+                  else
+                     # Appel serveur pour voir si la session est toujours active
+                     Session_Ended=$($ssh -i /root/.ssh/kpriv_mts -o StrictHostKeyChecking=no -o UserKnownHostsFile=/dev/null  -o "ProxyCommand=$basedir/ssh-proxy.sh -s $ssh $ViaProxy %h %p" MAW_Authentication@$SP_SSH1 -p $PortUsed AskConnectionMTS CHECKSESSIONFROMMTS $MagicNumber)
+                     if [ "$Session_Ended" = "SESSIONISDEAD" ]
+                        then
+                        rm -f /tmp/param_mts*
+                        # Si ce n'est pas un arret explicite de connexion on previent avec un warning que la session est termine
+                        # Pas de warning bien sur en cas de reconnexion automatique car on est deja en etat OFF d'un point de vue IHM
+                        if [ "$($uboot_environment_get MtsAnywhere)" != "" ]
+                           then
+                           $uboot_environment_set MtsAnywhere
+                           echo "*rem;proc:mtsanywhere off" | nc -w2 127.0.0.1 8000
+                           if [ "$IS_OTU" == "no" ]
+                              then
+                              echo -en "*rem\nprocess:warning \"\",\"SmartAcces connection stopped\nthe link to server dropped due to end of session\", STOP, 1,\"OK\",\"\",\"Press OK to continue\"\n" >/dev/tcp/127.0.0.1/8000
+                           fi
+                        fi
+                     else
+                        sleep $Wait_Before_Restart_Connection
+                        echo "relancer et tester ssh"
+                        $ssh -i /tmp/param_mts -o StrictHostKeyChecking=no  -o ExitOnForwardFailure=yes -o UserKnownHostsFile=/dev/null -o "ProxyCommand=$basedir/ssh-proxy.sh -s $ssh $ViaProxy %h %p" MAW_Connection@$ServerIp $RemoteForwardPorts $LocalForwardPorts -p $PortUsed -f $Max_sleep >/dev/null 2>/tmp/MAW_Connection
+                        RetCode=$?
+                        echo RETCODE:$RetCode    
+                        if [ "$RetCode" != 0 ]
+                           then
+                           # chec, on attend avant de faire une nouvelle tentative 
+                           Wait_Before_Restart_Connection=60
+                        else
+                           # tout semble bien se passer mais on verifie quand mme que le tunnel est tabli (par exemple il n'y a pas de retour d'erreur si  un port forwarding choue)
+                           Ssh_Pid=$(ps ax | grep ssh | grep MAW_Connection | grep param_mts |  head -n 1 | awk '{ print $1 }')
+                           if [ "$Ssh_Pid" != "" ]
+                              then
+                              # succs, on reset le temps d'attente
+                              Wait_Before_Restart_Connection=0
+                           fi
+                        fi  
+                     fi
                   fi
-                  sleep 10
-               done
-               # Si ce n'est pas un arret explicite de connexion on previent avec un warning que la connexion est perdue et on met a jour l'IHM pour etre coherent
-               # Pas de warning bien sur en cas de reconnexion automatique car on est deja en etat OFF d'un point de vue IHM
-               if [ "$($uboot_environment_get MtsAnywhere)" != "" ]
-                  then
-                  $uboot_environment_set MtsAnywhere
-                  echo "*rem;proc:mtsanywhere off" | nc -w2 127.0.0.1 8000
-                  if [ "$IS_OTU" == "no" ]
-                     then
-                     echo -en "*rem\nprocess:warning \"\",\"SmartAcces connection stopped\nthe link to server dropped due to end of session or network issue\", STOP, 1,\"OK\",\"\",\"Press OK to continue\"\n" >/dev/tcp/127.0.0.1/8000
-                  fi
-               fi
-               
+               done   
             fi 
             ) & ) &
          else
@@ -375,14 +428,13 @@ if [ "$1" == "CONNECT" -o "$1" == "RECONNECT" ]
       fi # [ "$RetCode" != 0 ]
 
       #cat /tmp/param_mts
-      rm -f /tmp/param_mts*
    else
       echo $RetCode
       echo RETCODE:$RetCode  
       if [ "$1" == "CONNECT" ] && [ "$IS_OTU" == "no" ]
          then
-         # affichage warning indiquant echec connexion d'authentification
-         echo -en "*rem\nprocess:warning \"\",\"Connection failed\", ERROR, 0,\"\",\"\",\"Hit any key to continue\"\n" >/dev/tcp/127.0.0.1/8000
+         # affichage warning indiquant echec connexion 
+         Warning_Connection_Failed
       fi 
    fi
 else
