@@ -1,5 +1,6 @@
 from jdsu.evm import *
 from jdsu.diag import *
+import jdsu.mts as mts
 import hashlib
 import os
 import os.path
@@ -13,9 +14,7 @@ eMMC_Blk = {
 
 @DIAG("Test eMMC")
 def t_emmc(cmd):
-    with open("/proc/device-tree/model") as ifile:
-        model = ifile.read().strip()
-    blk = eMMC_Blk[model]
+    blk = eMMC_Blk[mts.getMachineName()]
 
     md5buf  = -1
     md5buf2 = 0
